import json
import os

from api_1105 import log


def read_json(file_path):
    """读取json文件，将json文件对应的数据序列化为python对象再返回"""
    # 校验json文件的路径
    log.info(f"执行的函数为：read_json，描述为：读取json文件，将json文件的内容序列化为python对象在返回，传入的参数为：{file_path}")

    if isinstance(file_path, str) and os.path.isfile(file_path) and file_path.endswith(".json"):
        # 读取json文件
        with open(file_path, mode="r", encoding="utf-8") as f:
            try:
                # 将json文件对应的数据序列化为python对象再返回
                return json.loads(f.read())
            except Exception as e:
                log.error(
                    f"执行的函数为：read_json，描述为：读取json文件，将json文件的内容序列化为python对象在返回，传入的参数为：{file_path}, 文件路径不存在"
                    f"错误类型为：{type(e)}, 错误的描述为：{e}")
                raise e
    else:
        log.error(
            f"执行的函数为：read_json，描述为：读取json文件，将json文件的内容序列化为python对象在返回，传入的参数为：{file_path}, 文件路径不存在"
            f"错误类型为：FileNotFoundError, 错误的描述为：文件路径错误")
        raise FileNotFoundError("json文件的路径错误")